@@ -333,6 +333,67 @@ class DependenciesInstallError(Exception):
     pass
 
 
+@projection.command("update-lambda-dev")
+@click.option("--projection-dir", type=click.Path())
+@click.option(
+    "--dry-run",
+    is_flag=True,
+    default=False,
+    help="Enable dry run to verify inputs before actually submitting a custom projection to Gantry",
+)
+def update_lambda_dev(projection_dir, dry_run):
+    """
+    For Gantry's developers only: Upload a custom projection directly from a folder
+    that contains:
+        1. config.yaml: contains custom projection definition
+        2. function.zip: source code with all required dependencies to get invoked as a lambda
+    """
+    gantry.init()
+    api_client = gantry.get_client().log_store._api_client
+
+    click.secho("Parsing custom projection configs...", nl=False, fg="cyan")
+    projection = _get_custom_projection_configs(projection_dir)
+    click.secho("SUCCESS", fg="cyan")
+
+    click.secho("Validate custom projection definition...", nl=False, fg="cyan")
+    valid_config, err_msgs = _validate_custom_projection_configs(api_client, projection)
+    if not valid_config:
+        click.secho("FAILED.", fg="red")
+        if err_msgs:
+            click.secho("Please fix the following issue(s):", fg="red")
+            for err in err_msgs:
+                click.secho(f"\t{err}")
+
+        raise click.ClickException("Invalid projection definition")
+    click.secho("SUCCESS", fg="cyan")
+
+    if dry_run:
+        click.secho("Dry run complete.", fg="cyan")
+        return True
+
+    click.secho("Set up upload location...", nl=False, fg="cyan")
+    retrieved, resp = _get_s3_destination(api_client, projection)
+    if not retrieved:
+        click.secho("FAILED.", fg="red")
+        err_msg = resp.get("error", "")
+        raise click.ClickException(f"Fail to set up upload location {err_msg}")
+    click.secho("SUCCESS", fg="cyan")
+
+    upload_url, s3_key = resp["upload_url"], resp["s3_key"]
+    zip_filepath = f"{projection_dir}/function.zip"
+    proc = subprocess.run(["curl", "--upload-file", zip_filepath, upload_url])
+    if proc.returncode != 0:
+        return click.ClickException("Failed to upload custom projection function")
+
+    request_sent, task_id, err_msg = _async_update_custom_projection(api_client, s3_key, projection)
+    if not request_sent:
+        click.secho("FAILED.", fg="red")
+        raise click.ClickException(
+            f"Request to submit from-file custom projection failed: {err_msg}"
+        )
+    click.secho(f"SUCCESS. Task {task_id} has been submitted.", fg="cyan")
+
+
 @projection.command("update")
 @click.option("--projection-dir", type=click.Path())
 @click.option(
@@ -440,7 +501,7 @@ def _upload_function_zip(
 
 
 def _zip_function(projection_dir: str, zip_file: str) -> Tuple[bool, str]:
-    proc = subprocess.run(["zip", "-qr", zip_file, projection_dir])
+    proc = subprocess.run(["zip", "-qrj", zip_file, projection_dir])
     if proc.returncode != 0:
         return False, f"Failed to zip files under {projection_dir}"
     return True, ""
