@@ -309,7 +309,7 @@ class Gantry:
         feedback_ids: Optional[List[dict]] = None,
         feedbacks: Optional[Union[List[dict], pd.DataFrame]] = None,
         ignore_inputs: Optional[List[str]] = None,
-        timestamps: Optional[List[datetime.datetime]] = None,
+        timestamps: Optional[Union[List[datetime.datetime], pd.DatetimeIndex]] = None,
         sort_on_timestamp: bool = False,
         sample_rate: float = 1.0,
         as_batch: bool = False,
@@ -364,10 +364,10 @@ class Gantry:
                 is a dict of the features for the i-th prediction to be logged.
             ignore_inputs (optional, List[str]): A list of names of input features that should not
                 be monitored.
-            timestamps (optional, List[datetime.datetime]): A list of prediction timestamps.
-                If specified, `timestamps[i]` should be the timestamp for the i-th prediction.
-                If timestamps = None (default), then the prediction timestamp defaults to the
-                time when `log_records` is called.
+            timestamps (optional, Union[List[datetime.datetime], pd.DatetimeIndex): A list of
+                prediction timestamps. If specified, `timestamps[i]` should be the timestamps
+                for the i-th prediction. If timestamps = None (default), then the prediction
+                timestamp defaults to the time when `log_records` is called.
             sort_on_timestamp (bool, defaults to False): Works when timestamps are provided.
                 Sort using the given timestamp. Default to False.
             sample_rate: Used for downsampling. The probability as a float that each record
@@ -467,7 +467,7 @@ class Gantry:
         version: Optional[Union[int, str, List[Union[str, int]]]] = None,
         feedback_keys: Optional[List[str]] = None,
         ignore_inputs: Optional[List[str]] = None,
-        timestamps: Optional[List[datetime.datetime]] = None,
+        timestamps: Optional[Union[List[datetime.datetime], pd.DatetimeIndex]] = None,
         sort_on_timestamp: bool = False,
         sample_rate: float = 1.0,
         as_batch: bool = False,
@@ -789,7 +789,7 @@ class Gantry:
         feedback_ids: List[dict],
         feedbacks: Union[List[dict], pd.DataFrame],
         feedback_version: Optional[Union[str, int]] = None,
-        timestamps: Optional[List[datetime.datetime]] = None,
+        timestamps: Optional[Union[List[datetime.datetime], pd.DatetimeIndex]] = None,
         sort_on_timestamp: bool = False,
         sample_rate: float = 1.0,
         as_batch: bool = False,
@@ -987,7 +987,7 @@ class Gantry:
         feedback_keys: Optional[List[str]] = None,
         ignore_inputs: Optional[List[str]] = None,
         feedback_ids: Optional[List[dict]] = None,
-        timestamps: Optional[List[datetime.datetime]] = None,
+        timestamps: Optional[Union[List[datetime.datetime], pd.DatetimeIndex]] = None,
         sort_on_timestamp: bool = False,
         sample_rate: float = 1.0,
         as_batch: bool = False,
@@ -1029,7 +1029,7 @@ class Gantry:
             assert version is None or isinstance(version, list)  # mypy
 
             if len(inputs) == len(outputs):
-                if timestamps and not len(timestamps) == len(inputs):
+                if timestamps is not None and not len(timestamps) == len(inputs):
                     raise GantryLoggingException(
                         "timestamps don't have same length as inputs and outputs"
                     )
