@@ -84,7 +84,7 @@ def _create_timestamp_idx(
     minimize summarization window computing overhead by packing events of a single
     window into a single task.
     """
-    if timestamps:
+    if timestamps is not None:
         timestamp_idx: Iterable[Tuple[int, Any]] = enumerate(timestamps)
         if sort_on_timestamp:
             timestamp_idx = sorted(timestamp_idx, key=lambda el: el[1])
@@ -119,7 +119,12 @@ def _build_feedback_event(
 
     log_time = datetime.datetime.utcnow()
     event_time = timestamp if timestamp else log_time
-    check_event_time_in_future(event_time)
+    if check_event_time_in_future(event_time):
+        raise GantryLoggingException(
+            "Cannot log events from the future. "
+            f"Event timestep is {event_time}, but current time is {log_time}. "
+            "Please check your event times and re-submit all."
+        )
     log_time_str, event_time_str = log_time.isoformat(), event_time.isoformat()
 
     validate_logged_field_datatype(feedback, paths=["feedback"])
@@ -226,7 +231,12 @@ def _build_prediction_event(
 
     log_time = datetime.datetime.utcnow()
     event_time = custom_timestamp if custom_timestamp else log_time
-    check_event_time_in_future(event_time)
+    if check_event_time_in_future(event_time):
+        raise GantryLoggingException(
+            "Cannot log events from the future. "
+            f"Event timestep is {event_time}, but current time is {log_time}. "
+            "Please check your event times and re-submit all."
+        )
     log_time_str, event_time_str = log_time.isoformat(), event_time.isoformat()
 
     processed_tags = {"env": env}
