@@ -1011,7 +1011,9 @@ def test_log_feedback_invalid_timestamps(timestamps, cli_obj, caplog):
 @freeze_time(CURRENT_TIME)
 @pytest.mark.parametrize("tags", [{"env": "overwrite_env"}, {}, None])
 @pytest.mark.parametrize("sort", [False, True])
-@pytest.mark.parametrize("timestamps", [[ANOTHER_TIME, SOME_TIME], None])
+@pytest.mark.parametrize(
+    "timestamps", [pd.DatetimeIndex([ANOTHER_TIME, SOME_TIME]), [ANOTHER_TIME, SOME_TIME], None]
+)
 @pytest.mark.parametrize("random_error", [True, False])
 @pytest.mark.parametrize(
     "feedbacks",
@@ -1049,7 +1051,7 @@ def test_log_feedback(mock_uuid, feedbacks, random_error, timestamps, sort, tags
                 "feedback_version": 10,
                 "func_name": "foobar",
             },
-            "timestamp": SOME_TIME_STR if timestamps else CURRENT_TIME_STR,
+            "timestamp": SOME_TIME_STR if timestamps is not None else CURRENT_TIME_STR,
         },
         {
             "batch_id": None,
@@ -1063,11 +1065,11 @@ def test_log_feedback(mock_uuid, feedbacks, random_error, timestamps, sort, tags
                 "feedback_version": 10,
                 "func_name": "foobar",
             },
-            "timestamp": ANOTHER_TIME_STR if timestamps else CURRENT_TIME_STR,
+            "timestamp": ANOTHER_TIME_STR if timestamps is not None else CURRENT_TIME_STR,
         },
     ]
 
-    if timestamps:
+    if timestamps is not None:
         expected_events = [events[1], events[0]] if not sort else [events[0], events[1]]
     else:
         expected_events = [events[1], events[0]]
@@ -1084,7 +1086,9 @@ def test_log_feedback(mock_uuid, feedbacks, random_error, timestamps, sort, tags
 
 
 @pytest.mark.parametrize("sort", [False, True])
-@pytest.mark.parametrize("timestamps", [[ANOTHER_TIME, SOME_TIME], None])
+@pytest.mark.parametrize(
+    "timestamps", [pd.DatetimeIndex([ANOTHER_TIME, SOME_TIME]), [ANOTHER_TIME, SOME_TIME], None]
+)
 @pytest.mark.parametrize(
     "feedbacks",
     [
@@ -1114,7 +1118,9 @@ def test_log_feedback_sample_rate_0_5(mock_uuid, feedbacks, timestamps, sort):
 
 
 @pytest.mark.parametrize("sort", [False, True])
-@pytest.mark.parametrize("timestamps", [[ANOTHER_TIME, SOME_TIME], None])
+@pytest.mark.parametrize(
+    "timestamps", [pd.DatetimeIndex([ANOTHER_TIME, SOME_TIME]), [ANOTHER_TIME, SOME_TIME], None]
+)
 @pytest.mark.parametrize(
     "feedbacks",
     [
@@ -1144,7 +1150,9 @@ def test_log_feedback_sample_rate_0_5_none(mock_uuid, feedbacks, timestamps, sor
 
 
 @pytest.mark.parametrize("sort", [False, True])
-@pytest.mark.parametrize("timestamps", [[ANOTHER_TIME, SOME_TIME], None])
+@pytest.mark.parametrize(
+    "timestamps", [pd.DatetimeIndex([ANOTHER_TIME, SOME_TIME]), [ANOTHER_TIME, SOME_TIME], None]
+)
 @pytest.mark.parametrize(
     "feedbacks",
     [
@@ -1323,7 +1331,9 @@ def test_log_predictions_invalid_timestamps(timestamps, cli_obj, caplog):
 @freeze_time(CURRENT_TIME)
 @pytest.mark.parametrize("tags", [{"env": "overwrite_env"}, {}, None])
 @pytest.mark.parametrize("sort", [False, True])
-@pytest.mark.parametrize("timestamps", [[ANOTHER_TIME, SOME_TIME], None])
+@pytest.mark.parametrize(
+    "timestamps", [pd.DatetimeIndex([ANOTHER_TIME, SOME_TIME]), [ANOTHER_TIME, SOME_TIME], None]
+)
 @pytest.mark.parametrize("random_error", [True, False])
 @pytest.mark.parametrize(
     "outputs",
@@ -1375,7 +1385,7 @@ def test_log_predictions(mock_uuid, inputs, outputs, random_error, timestamps, s
             },
             "outputs": {"C": 303},
             "tags": tags if tags else {"env": "test"},
-            "timestamp": SOME_TIME_STR if timestamps else CURRENT_TIME_STR,
+            "timestamp": SOME_TIME_STR if timestamps is not None else CURRENT_TIME_STR,
         },
         {
             "batch_id": None,
@@ -1393,11 +1403,11 @@ def test_log_predictions(mock_uuid, inputs, outputs, random_error, timestamps, s
             },
             "outputs": {"C": 300},
             "tags": tags if tags else {"env": "test"},
-            "timestamp": ANOTHER_TIME_STR if timestamps else CURRENT_TIME_STR,
+            "timestamp": ANOTHER_TIME_STR if timestamps is not None else CURRENT_TIME_STR,
         },
     ]
 
-    if timestamps:
+    if timestamps is not None:
         expected_events = [events[1], events[0]] if not sort else [events[0], events[1]]
     else:
         expected_events = [events[1], events[0]]
@@ -1415,7 +1425,9 @@ def test_log_predictions(mock_uuid, inputs, outputs, random_error, timestamps, s
 
 @pytest.mark.parametrize("tags", [{"env": "overwrite_env"}, {}, None])
 @pytest.mark.parametrize("sort", [False, True])
-@pytest.mark.parametrize("timestamps", [[ANOTHER_TIME, SOME_TIME], None])
+@pytest.mark.parametrize(
+    "timestamps", [pd.DatetimeIndex([ANOTHER_TIME, SOME_TIME]), [ANOTHER_TIME, SOME_TIME], None]
+)
 @pytest.mark.parametrize(
     "outputs",
     [
@@ -1455,7 +1467,9 @@ def test_log_predictions_sample_rate_0_5(mock_uuid, inputs, outputs, timestamps,
 
 @pytest.mark.parametrize("tags", [{"env": "overwrite_env"}, {}, None])
 @pytest.mark.parametrize("sort", [False, True])
-@pytest.mark.parametrize("timestamps", [[ANOTHER_TIME, SOME_TIME], None])
+@pytest.mark.parametrize(
+    "timestamps", [pd.DatetimeIndex([ANOTHER_TIME, SOME_TIME]), [ANOTHER_TIME, SOME_TIME], None]
+)
 @pytest.mark.parametrize(
     "outputs",
     [
@@ -1495,7 +1509,9 @@ def test_log_predictions_sample_rate_0_5_none(mock_uuid, inputs, outputs, timest
 
 @pytest.mark.parametrize("tags", [{"env": "overwrite_env"}, {}, None])
 @pytest.mark.parametrize("sort", [False, True])
-@pytest.mark.parametrize("timestamps", [[ANOTHER_TIME, SOME_TIME], None])
+@pytest.mark.parametrize(
+    "timestamps", [pd.DatetimeIndex([ANOTHER_TIME, SOME_TIME]), [ANOTHER_TIME, SOME_TIME], None]
+)
 @pytest.mark.parametrize(
     "outputs",
     [
@@ -1759,6 +1775,7 @@ def test_log_predictions_and_feedbacks_size_mismatch(
     [
         [],
         [SOME_TIME, ANOTHER_TIME],
+        pd.DatetimeIndex([SOME_TIME, ANOTHER_TIME]),
     ],
 )
 def test_log_predictions_and_feedbacks_size_mismatch_timestamps(timestamps, cli_obj, log_store):
@@ -1797,7 +1814,9 @@ def test_log_predictions_and_feedbacks_size_mismatch_versions(version, cli_obj,
 
 @freeze_time(CURRENT_TIME)
 @pytest.mark.parametrize("tags", [{"env": "overwrite_env"}, {}, None])
-@pytest.mark.parametrize("timestamps", [None, [ANOTHER_TIME, SOME_TIME]])
+@pytest.mark.parametrize(
+    "timestamps", [None, pd.DatetimeIndex([ANOTHER_TIME, SOME_TIME]), [ANOTHER_TIME, SOME_TIME]]
+)
 @pytest.mark.parametrize("sort", [False, True])
 @pytest.mark.parametrize("as_batch", [False, True])
 @pytest.mark.parametrize(
@@ -1854,7 +1873,7 @@ def test_log_predictions_and_feedbacks_df(
 
     event_1 = {
         "batch_id": "batch-id-123" if as_batch else None,
-        "event_id": "ABCD2" if not (sort and timestamps) else "ABCD4",
+        "event_id": "ABCD2" if not (sort and timestamps is not None) else "ABCD4",
         "feedback": {"A": 200},
         "feedback_id": "5dd14615efeb2d086e519ed35efd3f73",
         "feedback_id_inputs": {"A": 100},
@@ -1871,12 +1890,12 @@ def test_log_predictions_and_feedbacks_df(
         },
         "outputs": {"B": 300},
         "tags": expected_tags,
-        "timestamp": ANOTHER_TIME_STR if timestamps else CURRENT_TIME_STR,
+        "timestamp": ANOTHER_TIME_STR if timestamps is not None else CURRENT_TIME_STR,
     }
 
     event_2 = {
         "batch_id": "batch-id-123" if as_batch else None,
-        "event_id": "ABCD4" if not (sort and timestamps) else "ABCD2",
+        "event_id": "ABCD4" if not (sort and timestamps is not None) else "ABCD2",
         "feedback": {"A": 201},
         "feedback_id": "9e329293e022d6cdaafdec49b5f4fedc",
         "feedback_id_inputs": {"A": 101},
@@ -1893,12 +1912,14 @@ def test_log_predictions_and_feedbacks_df(
         },
         "outputs": {"B": 301},
         "tags": expected_tags,
-        "timestamp": SOME_TIME_STR if timestamps else CURRENT_TIME_STR,
+        "timestamp": SOME_TIME_STR if timestamps is not None else CURRENT_TIME_STR,
     }
 
     assert log_store.logs == [
         {
-            "events": [event_1, event_2] if not (sort and timestamps) else [event_2, event_1],
+            "events": [event_1, event_2]
+            if not (sort and timestamps is not None)
+            else [event_2, event_1],
             "application": "foobar",
         },
     ]
