@@ -509,7 +509,6 @@ def test_describe(mock_series_describe, series_obj_factory):
 
 @pytest.mark.parametrize("dtype", ["int", "float"])
 @mock.patch("gantry.query.core.dataframe.GantrySeries.__getitem__")
-@mock.patch("gantry.query.core.dataframe.GantrySeries.count")
 @mock.patch("gantry.query.core.dataframe.GantrySeries.mean")
 @mock.patch("gantry.query.core.dataframe.GantrySeries.max")
 @mock.patch("gantry.query.core.dataframe.GantrySeries.min")
@@ -519,7 +518,6 @@ def test_private_describe_number(
     mock_min,
     mock_max,
     mock_mean,
-    mock_count,
     mock_get_item,
     dtype,
     series_obj_factory,
@@ -531,7 +529,8 @@ def test_private_describe_number(
     mock_min.return_value = 1
     mock_max.return_value = 10
     mock_mean.return_value = 5
-    mock_count.side_effect = [100, 1000, 10000]
+
+    series_obj.count.side_effect = [100, 1000, 10000]
 
     assert series_obj._describe() == {
         "count": 100,
@@ -549,16 +548,14 @@ def test_private_describe_number(
 
 
 @mock.patch("gantry.query.core.dataframe.GantrySeries.__getitem__")
-@mock.patch("gantry.query.core.dataframe.GantrySeries.count")
 def test_private_describe_bool(
-    mock_count,
     mock_get_item,
     series_obj_factory,
 ):
     series_obj = series_obj_factory("bool", parent_dataframe=mock.Mock(filters=[]))
 
     mock_get_item.return_value = series_obj
-    mock_count.side_effect = [100, 1000, 10000, 50000]
+    series_obj.count.side_effect = [100, 1000, 10000, 50000]
 
     assert series_obj._describe() == {
         "count": 100,
@@ -571,16 +568,14 @@ def test_private_describe_bool(
 
 
 @mock.patch("gantry.query.core.dataframe.GantrySeries.__getitem__")
-@mock.patch("gantry.query.core.dataframe.GantrySeries.count")
 def test_private_describe_str(
-    mock_count,
     mock_get_item,
     series_obj_factory,
 ):
     series_obj = series_obj_factory("str", parent_dataframe=mock.Mock(filters=[]))
 
     mock_get_item.return_value = series_obj
-    mock_count.side_effect = [100, 1000, 10000]
+    series_obj.count.side_effect = [100, 1000, 10000]
 
     assert series_obj._describe() == {
         "count": 100,
